==> telephone-sqlserver-3.0.15.jar: telephone/sqls/tel/getTelman_1.sql <==
select u.name,
quanbujieting,
weijie,
yijie,
 convert(float,round(jietingshichang,2)) as jietingshichang,
 convert(float,round(pingjun,2)) as pingjun,
 convert(float,round(yijie/(quanbujieting*1.0),2)) as jietinglv,
 waibo,
 convert(float,round(waiboshichang,2)) as waiboshichang,
 convert (float,(waiboshichang/(waibo*1.0))) as pingjunwaibo,
 zixundan,tousudan,baoxiudan,dianhuodan
from t_user u


--全部接听
left join
(SELECT telname as name,
		count(*) as quanbujieting from t_records WHERE

					teltype='呼入'
					AND { startDate != $$ : $ inltime > '{startDate}' $,
	                  startDate == $$ : $ 1 = 1 $,$$ }
				AND { endDate != $$ : $ inltime <= '{endDate}' $,
	                  endDate == $$ : $ 1 = 1 $,$$ }


				 GROUP BY  telname   ) q
				on q.name=u.name


-- 未接
left join
(SELECT telname as name,
		count(*) as weijie from t_records WHERE
					len(starttime) = 0
				and 	teltype='呼入'
				AND { startDate != $$ : $ inltime > '{startDate}' $,
	                  startDate == $$ : $ 1 = 1 $,$$ }
				AND { endDate != $$ : $ inltime <= '{endDate}' $,
	                  endDate == $$ : $ 1 = 1 $,$$ }
				 GROUP BY  telname   ) w
				on w.name=u.name
-- 已接
left join
(SELECT telname as name,
		count(*) as yijie from t_records WHERE
					len(starttime) != 0
				and 	teltype='呼入'
				AND { startDate != $$ : $ inltime > '{startDate}' $,
	                  startDate == $$ : $ 1 = 1 $,$$ }
				AND { endDate != $$ : $ inltime <= '{endDate}' $,
	                  endDate == $$ : $ 1 = 1 $,$$ }

				  GROUP BY  telname   ) y
				on y.name=u.name

--接听时长（分）
left join
(select telname as name,
		SUM(datediff(s, starttime, endtime))/60.00 as jietingshichang   from t_records WHERE
					len(starttime) != 0
				and 	teltype='呼入'
				AND len(endtime) != 0
			AND { startDate != $$ : $ starttime > '{startDate}' $,
	                  startDate == $$ : $ 1 = 1 $,$$ }
				AND { endDate != $$ : $ starttime <= '{endDate}' $,
	                  endDate == $$ : $ 1 = 1 $,$$ }
					GROUP BY telname) t
				on t.name=u.name
--呼入平均时长(分)
left join
(select telname as name,
           SUM(datediff(s,starttime,endtime))/(count(*)*60.0) as pingjun from t_records WHERE
		   LEN(starttime) != 0
			 and teltype='呼入'
			 and len(endtime)!=0
			 AND { startDate != $$ : $ starttime > '{startDate}' $,
	                  startDate == $$ : $ 1 = 1 $,$$ }
				AND { endDate != $$ : $ starttime <= '{endDate}' $,
	                  endDate == $$ : $ 1 = 1 $,$$ }

					GROUP BY telname) z
					on z.name=u.name

--外拨数量
left join
(select f_name as name,
           count(*) as waibo from T_CALL_LOG WHERE
		  	islink = 'BZ_CALLOUT'
			  AND { startDate != $$ : $ comingtime > '{startDate}' $,
	                  startDate == $$ : $ 1 = 1 $,$$ }
				AND { endDate != $$ : $ comingtime <= '{endDate}' $,
	                  endDate == $$ : $ 1 = 1 $,$$ }
					GROUP BY f_name) f
					on f.name=u.name
--外拨时长(分)
left join
(select f_name as name,
SUM(datediff(s,comingtime,handuptime))/60.00 as waiboshichang from T_CALL_LOG WHERE
  islink='BZ_CALLOUT'
  AND { startDate != $$ : $ comingtime > '{startDate}' $,
	                  startDate == $$ : $ 1 = 1 $,$$ }
				AND { endDate != $$ : $ comingtime <= '{endDate}' $,
	                  endDate == $$ : $ 1 = 1 $,$$ }
					GROUP BY f_name) x
					on x.name=u.name

--咨询单
left join
(select f_operator_name as name,
count(*) as zixundan from t_consult WHERE
    { startDate != $$ : $ f_created_date > '{startDate}' $,
	                  startDate == $$ : $ 1 = 1 $,$$ }
				AND { endDate != $$ : $ f_created_date <= '{endDate}' $,
	                  endDate == $$ : $ 1 = 1 $,$$ }
					GROUP BY f_operator_name) c
					on c.name=u.name

--投诉单
left join
(select f_operator_name as name,
count(*) as tousudan from t_complaint WHERE
   { startDate != $$ : $ f_created_date > '{startDate}' $,
	                  startDate == $$ : $ 1 = 1 $,$$ }
				AND { endDate != $$ : $ f_created_date <= '{endDate}' $,
	                  endDate == $$ : $ 1 = 1 $,$$ }
					GROUP BY f_operator_name) b
					on b.name=u.name
--报修单
left join
(select f_attendant as name,
count(*) as baoxiudan from t_service WHERE
   { startDate != $$ : $ f_created_date > '{startDate}' $,
	                  startDate == $$ : $ 1 = 1 $,$$ }
				AND { endDate != $$ : $ f_created_date <= '{endDate}' $,
	                  endDate == $$ : $ 1 = 1 $,$$ }  and
	(f_repairtype != '点火通气' )
					GROUP BY f_attendant) a
					on a.name=u.name
--点火通气单
left join
(select f_attendant as name,
count(*) as dianhuodan from t_service WHERE

 { startDate != $$ : $ f_created_date > '{startDate}' $,
	                  startDate == $$ : $ 1 = 1 $,$$ }
				AND { endDate != $$ : $ f_created_date <= '{endDate}' $,
	                  endDate == $$ : $ 1 = 1 $,$$ }   and
  (f_repairtype = '点火通气' )
					GROUP BY f_attendant) d
					on d.name=u.name
where
        u.rolestr like '%话务员%'

==> telephone-sqlserver-3.0.20.jar: telephone/sqls/tel/getTelman_1.sql <==
select
    u.name,
	quanbujieting, -- 全部接听数
	weijie, -- 未接数
	yijie, -- 已接数
	 convert(float,round(jietingshichang,2)) as jietingshichang, -- 接听时长
	 convert(float,round(pingjun,2)) as pingjun, -- 平均
	 convert(float,round(yijie/(quanbujieting*1.0),2)) as jietinglv, -- 接听率
	 waibo, -- 外拨
	 convert(float,round(waiboshichang,2)) as waiboshichang, --外拨时长
	 convert (float,(waiboshichang/(waibo*1.0))) as pingjunwaibo, -- 平均外拨
	 zixundan,  -- 咨询单数
	 tousudan, -- 投诉单数
	 baoxiudan, -- 报修单数
	 dianhuodan -- 点火单数
from t_user u
--全部接听
left join
(SELECT telname as name,
		count(*) as quanbujieting from t_records WHERE

					teltype='呼入'
					AND { startDate != $$ : $ inltime > '{startDate}' $,
	                  startDate == $$ : $ 1 = 1 $,$$ }
				AND { endDate != $$ : $ inltime <= '{endDate}' $,
	                  endDate == $$ : $ 1 = 1 $,$$ }


				 GROUP BY  telname   ) q
				on q.name=u.name


-- 未接
left join
(SELECT telname as name,
		count(*) as weijie from t_records WHERE
					len(starttime) = 0
				and 	teltype='呼入'
				AND { startDate != $$ : $ inltime > '{startDate}' $,
	                  startDate == $$ : $ 1 = 1 $,$$ }
				AND { endDate != $$ : $ inltime <= '{endDate}' $,
	                  endDate == $$ : $ 1 = 1 $,$$ }
				 GROUP BY  telname   ) w
				on w.name=u.name
-- 已接
left join
(
	SELECT telname as name,
	       count(*) as yijie from t_records WHERE len(starttime) != 0 and 	teltype='呼入'
		AND { startDate != $$ : $ inltime > '{startDate}' $,
			  startDate == $$ : $ 1 = 1 $,$$ }
		AND { endDate != $$ : $ inltime <= '{endDate}' $,
			  endDate == $$ : $ 1 = 1 $,$$ }
		GROUP BY  telname
) y
on y.name=u.name

--接听时长（分）
left join
(select telname as name,
		SUM(datediff(s, starttime, endtime))/60.00 as jietingshichang   from t_records WHERE
					len(starttime) != 0
				and 	teltype='呼入'
				AND len(endtime) != 0
			AND { startDate != $$ : $ starttime > '{startDate}' $,
	                  startDate == $$ : $ 1 = 1 $,$$ }
				AND { endDate != $$ : $ starttime <= '{endDate}' $,
	                  endDate == $$ : $ 1 = 1 $,$$ }
					GROUP BY telname) t
				on t.name=u.name
--呼入平均时长(分)
left join
(select telname as name,
           SUM(datediff(s,starttime,endtime))/(count(*)*60.0) as pingjun from t_records WHERE
		   LEN(starttime) != 0
			 and teltype='呼入'
			 and len(endtime)!=0
			 AND { startDate != $$ : $ starttime > '{startDate}' $,
	                  startDate == $$ : $ 1 = 1 $,$$ }
				AND { endDate != $$ : $ starttime <= '{endDate}' $,
	                  endDate == $$ : $ 1 = 1 $,$$ }

					GROUP BY telname) z
					on z.name=u.name

--外拨数量
left join
(select f_name as name,
           count(*) as waibo from T_CALL_LOG WHERE
		  	islink = 'BZ_CALLOUT'
			  AND { startDate != $$ : $ comingtime > '{startDate}' $,
	                  startDate == $$ : $ 1 = 1 $,$$ }
				AND { endDate != $$ : $ comingtime <= '{endDate}' $,
	                  endDate == $$ : $ 1 = 1 $,$$ }
					GROUP BY f_name) f
					on f.name=u.name
--外拨时长(分)
left join
(select f_name as name,
SUM(datediff(s,comingtime,handuptime))/60.00 as waiboshichang from T_CALL_LOG WHERE
  islink='BZ_CALLOUT'
  AND { startDate != $$ : $ comingtime > '{startDate}' $,
	                  startDate == $$ : $ 1 = 1 $,$$ }
				AND { endDate != $$ : $ comingtime <= '{endDate}' $,
	                  endDate == $$ : $ 1 = 1 $,$$ }
					GROUP BY f_name) x
					on x.name=u.name

--咨询单
left join
(select f_operator_name as name,
count(*) as zixundan from t_consult WHERE
    { startDate != $$ : $ f_created_date > '{startDate}' $,
	                  startDate == $$ : $ 1 = 1 $,$$ }
				AND { endDate != $$ : $ f_created_date <= '{endDate}' $,
	                  endDate == $$ : $ 1 = 1 $,$$ }
					GROUP BY f_operator_name) c
					on c.name=u.name

--投诉单
left join
(select f_operator_name as name,
count(*) as tousudan from t_complaint WHERE
   { startDate != $$ : $ f_created_date > '{startDate}' $,
	                  startDate == $$ : $ 1 = 1 $,$$ }
				AND { endDate != $$ : $ f_created_date <= '{endDate}' $,
	                  endDate == $$ : $ 1 = 1 $,$$ }
					GROUP BY f_operator_name) b
					on b.name=u.name
--报修单
left join
(select f_attendant as name,
count(*) as baoxiudan from t_service WHERE
   { startDate != $$ : $ f_created_date > '{startDate}' $,
	                  startDate == $$ : $ 1 = 1 $,$$ }
				AND { endDate != $$ : $ f_created_date <= '{endDate}' $,
	                  endDate == $$ : $ 1 = 1 $,$$ }  and
	(f_repairtype != '点火通气' )
					GROUP BY f_attendant) a
					on a.name=u.name
--点火通气单
left join
(select f_attendant as name,
count(*) as dianhuodan from t_service WHERE

 { startDate != $$ : $ f_created_date > '{startDate}' $,
	                  startDate == $$ : $ 1 = 1 $,$$ }
				AND { endDate != $$ : $ f_created_date <= '{endDate}' $,
	                  endDate == $$ : $ 1 = 1 $,$$ }   and
  (f_repairtype = '点火通气' )
					GROUP BY f_attendant) d
					on d.name=u.name
where
        u.rolestr like '%话务员%'
